@@ -1,4 +1,4 @@
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -17,7 +17,7 @@
 # Miscellaneous utility classes and functions for the dx-app-wizard
 # command-line tool
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 import os, shutil, subprocess, re, json
 
