@@ -1,8 +1,24 @@
 # -*- coding: utf-8 -*-
+#
+# Copyright (C) 2013-2014 DNAnexus, Inc.
+#
+# This file is part of dx-toolkit (DNAnexus platform client libraries).
+#
+#   Licensed under the Apache License, Version 2.0 (the "License"); you may not
+#   use this file except in compliance with the License. You may obtain a copy
+#   of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#   License for the specific language governing permissions and limitations
+#   under the License.
 
 from __future__ import print_function
 
-import platform, locale, sys
+import platform, locale
 sys_encoding = locale.getdefaultlocale()[1] or 'UTF-8'
 if platform.python_implementation() != "PyPy":
     try:
@@ -18,10 +34,11 @@ import dxpy
 
 _run_all_tests = 'DXTEST_FULL' in os.environ
 TEST_CREATE_APPS = _run_all_tests or 'DXTEST_CREATE_APPS' in os.environ
-TEST_FUSE = _run_all_tests or 'DXTEST_FUSE' in os.environ
-TEST_RUN_JOBS = _run_all_tests or 'DXTEST_RUN_JOBS' in os.environ
-TEST_HTTP_PROXY = _run_all_tests or 'DXTEST_HTTP_PROXY' in os.environ
 TEST_ENV = _run_all_tests or 'DXTEST_ENV' in os.environ
+TEST_FUSE = _run_all_tests or 'DXTEST_FUSE' in os.environ
+TEST_HTTP_PROXY = _run_all_tests or 'DXTEST_HTTP_PROXY' in os.environ
+TEST_NO_RATE_LIMITS = _run_all_tests or 'DXTEST_NO_RATE_LIMITS' in os.environ
+TEST_RUN_JOBS = _run_all_tests or 'DXTEST_RUN_JOBS' in os.environ
 TEST_TCSH = _run_all_tests or 'DXTEST_TCSH' in os.environ
 
 class DXTestCase(unittest.TestCase):
