@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -17,14 +17,11 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
-import os, unittest, tempfile, filecmp
+import os, unittest, tempfile, filecmp, time, json, sys
 
 import dxpy
 import dxpy_testutil as testutil
-from dxpy.utils.describe import get_field_from_jbor, get_job_from_jbor, is_job_ref
-from dxpy.exceptions import *
-from dxpy.bindings import *
-
+from dxpy.exceptions import DXAPIError, DXFileError, DXError, DXJobFailureError
 from dxpy.utils import pretty_print
 
 def get_objects_from_listf(listf):
@@ -238,6 +235,23 @@ class TestDXFile(unittest.TestCase):
             buf = same_dxfile.read()
             self.assertEqual(self.foo_str[1:], buf)
 
+            same_dxfile.seek(1, 0)
+            buf = same_dxfile.read()
+            self.assertEqual(self.foo_str[1:], buf)
+
+            same_dxfile.seek(2)
+            same_dxfile.seek(-1, 1)
+            buf = same_dxfile.read()
+            self.assertEqual(self.foo_str[1:], buf)
+
+            same_dxfile.seek(0, 2)
+            buf = same_dxfile.read()
+            self.assertEqual(b"", buf)
+
+            same_dxfile.seek(-1, 2)
+            buf = same_dxfile.read()
+            self.assertEqual(self.foo_str[-1:], buf)
+
     def test_iter_dxfile(self):
         dxid = ""
         with dxpy.new_dxfile() as self.dxfile:
